Module file_finder

Module file_finder 

Structs

FileFinder
File finder with fuzzy matching and caching Uses the ignore crate from ripgrep to automatically respect .gitignore
FileMatch
Represents a matched file with fuzzy score