Browser client - shared API for browser automation
Provides a high-level API for browser operations used by both the TUI command and the agent tool.
Structs
- Browser
Client - Browser client for high-level operations
Browser client - shared API for browser automation
Provides a high-level API for browser operations used by both the TUI command and the agent tool.