Browser tool for LLM agent
Implements the Tool trait for browser automation in the agent system.
Structs
- Browser
Tool - Browser automation tool for the LLM agent
Browser tool for LLM agent
Implements the Tool trait for browser automation in the agent system.