Module activity

Module activity 

Activity message formatting for TUI

Formats tool execution messages for display in the activity feed.

Functions

format_activity_message
Format a tool activity message based on tool name and arguments