pub struct InputHistory { /* private fields */ }Expand description
Input history with navigation support
Implementations
Sourceimpl InputHistory
impl InputHistory
Sourcepub fn with_max_size(max_size: usize) -> Self
pub fn with_max_size(max_size: usize) -> Self
Create a new history with custom max size
Sourcepub fn add(&mut self, text: &str)
pub fn add(&mut self, text: &str)
Add a new entry to history
- Ignores empty strings
- Ignores duplicates of the most recent entry
- Truncates to max_size if needed
Navigate to previous (older) entry
Returns the entry at the new position, or None if at the oldest Saves current draft before navigation starts
Navigate to next (newer) entry
Returns the entry at the new position, or restores draft if at newest
Check if currently navigating history
Sourcepub fn saved_draft(&self) -> Option<&str>
pub fn saved_draft(&self) -> Option<&str>
Get saved draft (text before navigation started)
Reset navigation state